@@ -247,7 +247,7 @@ class Dlg extends Handler_Protected {
 		print "<input dojoType=\"dijit.form.TextBox\" style=\"display : none\" name=\"op\" value=\"rpc\">";
 		print "<input dojoType=\"dijit.form.TextBox\" style=\"display : none\" name=\"method\" value=\"addfeed\">";
 
-		print "<div class=\"dlgSec\">".__("Feed")."</div>";
+		print "<div class=\"dlgSec\">".__("Feed or site URL")."</div>";
 		print "<div class=\"dlgSecCont\">";
 
 		print "<div style='float : right'>
@@ -256,7 +256,7 @@ class Dlg extends Handler_Protected {
 				theme_image($this->link, 'images/indicator_white.gif')."'></div>";
 
 		print "<input style=\"font-size : 16px; width : 20em;\"
-			placeHolder=\"".__("Feed URL")."\"
+			placeHolder=\"".__("Feed or site URL")."\"
 			dojoType=\"dijit.form.ValidationTextBox\" required=\"1\" name=\"feed\" id=\"feedDlg_feedUrl\">";
 
 		print "<hr/>";
@@ -291,8 +291,7 @@ class Dlg extends Handler_Protected {
 				" <input
 					placeHolder=\"".__("Password")."\"
 					dojoType=\"dijit.form.TextBox\" type='password'
-					style=\"width : 10em;\" name='pass'\">".
-				" <p class='insensitive'>".__("OAuth will be used automatically for Twitter feeds.")."</p>
+					style=\"width : 10em;\" name='pass'\">
 			</div></div>";
 
 
@@ -376,27 +375,9 @@ class Dlg extends Handler_Protected {
 
 		print "<div class=\"dlgSecCont\">";
 
-		if (!SPHINX_ENABLED) {
-
-			print "<input dojoType=\"dijit.form.ValidationTextBox\"
-				style=\"font-size : 16px; width : 12em;\"
-				required=\"1\" name=\"query\" type=\"search\" value=''>";
-
-			print " " . __('match on')." ";
-
-			$search_fields = array(
-				"title" => __("Title"),
-					"content" => __("Content"),
-				"both" => __("Title or content"));
-
-			print_select_hash("match_on", 3, $search_fields,
-				'dojoType="dijit.form.Select"');
-		} else {
-			print "<input dojoType=\"dijit.form.ValidationTextBox\"
-				style=\"font-size : 16px; width : 20em;\"
-				required=\"1\" name=\"query\" type=\"search\" value=''>";
-		}
-
+		print "<input dojoType=\"dijit.form.ValidationTextBox\"
+			style=\"font-size : 16px; width : 20em;\"
+			required=\"1\" name=\"query\" type=\"search\" value=''>";
 
 		print "<hr/>".__('Limit search to:')." ";
 
@@ -435,7 +416,7 @@ class Dlg extends Handler_Protected {
 
 		if (!SPHINX_ENABLED) {
 			print "<div style=\"float : left\">
-				<a class=\"visibleLink\" target=\"_blank\" href=\"http://tt-rss.org/redmine/wiki/tt-rss/SearchSyntax\">Search syntax</a>
+				<a class=\"visibleLink\" target=\"_blank\" href=\"http://tt-rss.org/wiki/SearchSyntax\">Search syntax</a>
 				</div>";
 		}
 
@@ -623,7 +604,7 @@ class Dlg extends Handler_Protected {
 
 		print "</div>";
 
-		$details = "http://tt-rss.org/redmine/versions/show/$id";
+		$details = "http://tt-rss.org/redmine/versions/$id";
 		$download = "http://tt-rss.org/#Download";
 
 		print "<p align='center'>".__("You can update using built-in updater in the Preferences or by using update.php")."</p>";
