@@ -1,4 +1,6 @@
 <?php
+require_once "colors.php";
+
 class Feeds extends Handler_Protected {
 
 	function csrf_ignore($method) {
@@ -7,6 +9,18 @@ class Feeds extends Handler_Protected {
 		return array_search($method, $csrf_ignored) !== false;
 	}
 
+	private function make_gradient($end, $class) {
+		$start = $class == "even" ? "#f0f0f0" : "#ffffff";
+
+		return "style='background: linear-gradient(left , $start 6%, $end 100%);
+			background: -o-linear-gradient(left , $start 6%, $end 100%);
+			background: -moz-linear-gradient(left , $start 6%, $end 100%);
+			background: -webkit-linear-gradient(left , $start 6%, $end 100%);
+			background: -ms-linear-gradient(left , $start 6%, $end 100%);
+			background: -webkit-gradient(linear, left top, right top,
+				color-stop(0.06, $start), color-stop(1, $end));'";
+	}
+
 	private function format_headline_subtoolbar($feed_site_url, $feed_title,
 			$feed_id, $is_cat, $search, $match_on,
 			$search_mode, $view_mode, $error) {
@@ -31,6 +45,8 @@ class Feeds extends Handler_Protected {
 		$tog_marked_link = "selectionToggleMarked()";
 		$tog_published_link = "selectionTogglePublished()";
 
+		$set_score_link = "setSelectionScore()";
+
 		if ($is_cat) $cat_q = "&is_cat=$is_cat";
 
 		if ($search) {
@@ -45,6 +61,7 @@ class Feeds extends Handler_Protected {
 		// right part
 
 		$reply .= "<span class='r'>";
+		$reply .= "<span id='feed_title'>";
 
 		if ($feed_site_url) {
 			$target = "target=\"_blank\"";
@@ -59,6 +76,8 @@ class Feeds extends Handler_Protected {
 			$reply .= $feed_title;
 		}
 
+		$reply .= "</span>";
+
 		$reply .= "
 			<a href=\"#\"
 				title=\"".__("View as RSS feed")."\"
@@ -90,6 +109,7 @@ class Feeds extends Handler_Protected {
 		$reply .= "<option value=\"0\" disabled=\"1\">".__('Selection:')."</option>";
 
 		$reply .= "<option value=\"$catchup_sel_link\">".__('Mark as read')."</option>";
+		$reply .= "<option value=\"$set_score_link\">".__('Set score')."</option>";
 
 		if ($feed_id != "0") {
 			$reply .= "<option value=\"$archive_sel_link\">".__('Archive')."</option>";
@@ -134,9 +154,22 @@ class Feeds extends Handler_Protected {
 
 		$method_split = explode(":", $method);
 
-		if ($method == "ForceUpdate" && $feed && is_numeric($feed) > 0) {
-			include "rssfuncs.php";
-			update_rss_feed($this->link, $feed, true);
+		if ($method == "ForceUpdate" && $feed > 0 && is_numeric($feed)) {
+			// Update the feed if required with some basic flood control
+
+			$result = db_query($this->link,
+				"SELECT cache_images,".SUBSTRING_FOR_DATE."(last_updated,1,19) AS last_updated
+					FROM ttrss_feeds WHERE id = '$feed'");
+
+				if (db_num_rows($result) != 0) {
+					$last_updated = strtotime(db_fetch_result($result, 0, "last_updated"));
+					$cache_images = sql_bool_to_bool(db_fetch_result($result, 0, "cache_images"));
+
+					if (!$cache_images && time() - $last_updated > 120 || isset($_REQUEST['DevForceUpdate'])) {
+						include "rssfuncs.php";
+						update_rss_feed($this->link, $feed, true, true);
+					}
+				}
 		}
 
 		if ($method_split[0] == "MarkAllReadGR")  {
@@ -182,11 +215,7 @@ class Feeds extends Handler_Protected {
 		}
 
 		@$search_mode = db_escape_string($_REQUEST["search_mode"]);
-		@$match_on = db_escape_string($_REQUEST["match_on"]);
-
-		if (!$match_on) {
-			$match_on = "both";
-		}
+		$match_on = "both"; // deprecated, TODO: remove
 
 		if ($_REQUEST["debug"]) $timing_info = print_checkpoint("H0", $timing_info);
 
@@ -208,22 +237,17 @@ class Feeds extends Handler_Protected {
 
 		$vgroup_last_feed = $vgr_last_feed;
 
-//		if (!$offset) {
-
-			if (db_num_rows($result) > 0) {
-				$reply['toolbar'] = $this->format_headline_subtoolbar($feed_site_url,
-					$feed_title,
-					$feed, $cat_view, $search, $match_on, $search_mode, $view_mode,
-					$last_error);
-			}
-//		}
+		$reply['toolbar'] = $this->format_headline_subtoolbar($feed_site_url,
+			$feed_title,
+			$feed, $cat_view, $search, $match_on, $search_mode, $view_mode,
+			$last_error);
 
 		$headlines_count = db_num_rows($result);
 
 		if (get_pref($this->link, 'COMBINED_DISPLAY_MODE')) {
 			$button_plugins = array();
 			foreach (explode(",", ARTICLE_BUTTON_PLUGINS) as $p) {
-				$pclass = trim("button_${p}");
+				$pclass = "button_" . trim($p);
 
 				if (class_exists($pclass)) {
 					$plugin = new $pclass($link);
@@ -250,6 +274,7 @@ class Feeds extends Handler_Protected {
 				$feed_id = $line["feed_id"];
 				$label_cache = $line["label_cache"];
 				$labels = false;
+				$label_row_style = "";
 
 				if ($label_cache) {
 					$label_cache = json_decode($label_cache, true);
@@ -264,6 +289,22 @@ class Feeds extends Handler_Protected {
 
 				if (!is_array($labels)) $labels = get_article_labels($this->link, $id);
 
+				if (count($labels) > 0) {
+					for ($i = 0; $i < min(4, count($labels)); $i++) {
+						$bg = rgb2hsl(_color_unpack($labels[$i][3]));
+
+						if ($bg && $bg[1] > 0) {
+							$bg[1] = 0.1;
+							$bg[2] = 1;
+
+							$bg = _color_pack(hsl2rgb($bg));
+							$label_row_style = $this->make_gradient($bg, $class);;
+
+							break;
+						}
+					}
+				}
+
 				$labels_str = "<span id=\"HLLCTR-$id\">";
 				$labels_str .= format_article_labels($labels, $id);
 				$labels_str .= "</span>";
@@ -348,7 +389,7 @@ class Feeds extends Handler_Protected {
 				$score_pic = "<img class='hlScorePic' src=\"images/$score_pic\"
 					onclick=\"adjustArticleScore($id, $score)\" title=\"$score $score_title\">"; */
 
-				$score_pic = "<img class='hlScorePic' src=\"$score_pic\"
+				$score_pic = "<img class='hlScorePic' score='$score' onclick='changeScore($id, this)' src=\"$score_pic\"
 					title=\"$score\">";
 
 				if ($score > 500) {
@@ -396,7 +437,7 @@ class Feeds extends Handler_Protected {
 					$mouseover_attrs = "onmouseover='postMouseIn($id)'
 						onmouseout='postMouseOut($id)'";
 
-					$reply['content'] .= "<div class='$class' id='RROW-$id' $mouseover_attrs>";
+					$reply['content'] .= "<div class='$class' id='RROW-$id' $label_row_style $mouseover_attrs>";
 
 					$reply['content'] .= "<div class='hlUpdPic'>$update_pic</div>";
 
@@ -487,7 +528,7 @@ class Feeds extends Handler_Protected {
 					$mouseover_attrs = "onmouseover='postMouseIn($id)'
 						onmouseout='postMouseOut($id)'";
 
-					$reply['content'] .= "<div class=\"$class\"
+					$reply['content'] .= "<div class=\"$class\" $label_row_style
 						id=\"RROW-$id\" $mouseover_attrs'>";
 
 					$reply['content'] .= "<div class=\"cdmHeader\">";
@@ -503,7 +544,7 @@ class Feeds extends Handler_Protected {
 					$reply['content'] .= "</div>";
 
 					$reply['content'] .= "<div id=\"PTITLE-FULL-$id\" style=\"display : none\">" .
-						strip_tags($line['title']) . "</div>";
+						htmlspecialchars(strip_tags($line['title'])) . "</div>";
 
 					$reply['content'] .= "<span id=\"RTITLE-$id\"
 						onclick=\"return cdmClicked(event, $id);\"
@@ -596,7 +637,7 @@ class Feeds extends Handler_Protected {
 					$reply['content'] .= "</div>";
 
 					$reply['content'] .= "<span id=\"CWRAP-$id\">";
-					$reply['content'] .= $expand_cdm ? $article_content : '';
+					$reply['content'] .= $article_content;
 					$reply['content'] .= "</span>";
 
 /*					$tmp_result = db_query($this->link, "SELECT always_display_enclosures FROM
@@ -633,14 +674,14 @@ class Feeds extends Handler_Protected {
 
 					if ($num_comments > 0) {
 						if ($line["comments"]) {
-							$comments_url = $line["comments"];
+							$comments_url = htmlspecialchars($line["comments"]);
 						} else {
-							$comments_url = $line["link"];
+							$comments_url = htmlspecialchars($line["link"]);
 						}
 						$entry_comments = "<a target='_blank' href=\"$comments_url\">$num_comments comments</a>";
 					} else {
 						if ($line["comments"] && $line["link"] != $line["comments"]) {
-							$entry_comments = "<a target='_blank' href=\"".$line["comments"]."\">comments</a>";
+							$entry_comments = "<a target='_blank' href=\"".htmlspecialchars($line["comments"])."\">comments</a>";
 						}
 					}
 
