@@ -15,30 +15,30 @@
 	require_once "db-prefs.php";
 	require_once "update_self.php";
 
-	if (!defined('STDIN')) {
+	if (!defined('PHP_EXECUTABLE'))
+		define('PHP_EXECUTABLE', '/usr/bin/php');
+
+	$op = $argv;
+
+	if (count($argv) == 0 && !defined('STDIN')) {
 		?> <html>
 		<head>
-		<title>Database Updater</title>
+		<title>Tiny Tiny RSS data update script.</title>
 		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 		<link rel="stylesheet" type="text/css" href="utility.css">
 		</head>
 
 		<body>
 		<div class="floatingLogo"><img src="images/logo_wide.png"></div>
-		<h1><?php echo __("Update") ?></h1>
+		<h1><?php echo __("Tiny Tiny RSS data update script.") ?></h1>
 
-		<?php print_error("Please run this script from the command line."); ?>
+		<?php print_error("Please run this script from the command line. Use option \"-help\" to display command help if this error is displayed erroneously."); ?>
 
 		</body></html>
 	<?php
 		exit;
 	}
 
-	if (!defined('PHP_EXECUTABLE'))
-		define('PHP_EXECUTABLE', '/usr/bin/php');
-
-	$op = $argv;
-
 	if (count($argv) == 1 || in_array("-help", $op) ) {
 		print "Tiny Tiny RSS data update script.\n\n";
 		print "Options:\n";
@@ -52,6 +52,7 @@
 		print "  -quiet              - don't show messages\n";
 		print "  -indexes            - recreate missing schema indexes\n";
 		print "  -convert-filters    - convert type1 filters to type2\n";
+		print "  -force-update       - force update of all feeds\n";
 		print "  -help               - show this help\n";
 		return;
 	}
@@ -289,6 +290,13 @@
 
 	}
 
+	if (in_array("-force-update", $op)) {
+		_debug("marking all feeds as needing update...");
+
+		db_query($link, "UPDATE ttrss_feeds SET last_update_started = '1970-01-01',
+				last_updated = '1970-01-01'");
+	}
+
 	db_close($link);
 
 	if ($lock_handle != false) {
